/// <reference types="node" />
import { Writable } from "stream";
import { PackerResult } from "../packer";
import { ProviderImpl, CommonOptions, ReceivableMessage, FunctionStats } from "../provider";
import { AsyncQueue } from "../throttle";
import { Wrapper, WrapperOptions } from "../wrapper";
import { CostSnapshot } from "../cost";
/**
 * @public
 */
export interface LocalState {
    /** @internal */
    wrappers: Wrapper[];
    /** @internal */
    getWrapper: () => Promise<Wrapper>;
    /** @internal */
    logStreams: Writable[];
    tempDir: string;
    logUrl: string;
    /** @internal */
    gcPromise?: Promise<void>;
    /** @internal */
    queue: AsyncQueue<ReceivableMessage>;
    options: Required<LocalOptions>;
}
/**
 * Local provider options for {@link faastLocal}. Extends {@link CommonOptions}.
 *
 * @public
 */
export interface LocalOptions extends CommonOptions {
    /** @internal */
    _gcWorker?: (tempdir: string) => Promise<void>;
}
export declare function defaultGcWorker(dir: string): Promise<void>;
export declare const defaults: Required<LocalOptions>;
export declare const LocalImpl: ProviderImpl<LocalOptions, LocalState>;
export declare function logUrl(state: LocalState): string;
export declare function localPacker(functionModule: string, parentDir: string, options: CommonOptions, wrapperOptions: WrapperOptions, FunctionName: string): Promise<PackerResult>;
export declare function costSnapshot(state: LocalState, stats: FunctionStats): Promise<CostSnapshot>;
