/// <reference types="node" />
import * as childProcess from "child_process";
import { Deferred } from "./throttle";
import { AnyFunction } from "./types";
export declare const filename: string;
export interface CallId {
    callId: string;
}
export interface Trampoline {
    trampoline: AnyFunction;
}
export interface TrampolineFactory {
    filename: string;
    makeTrampoline: (wrapper: Wrapper) => Trampoline;
}
export interface FunctionCall extends CallId {
    name: string;
    modulePath: string;
    args: any[];
    ResponseQueueId?: string;
}
export interface FunctionReturn extends CallId {
    type: "returned" | "error";
    value?: any;
    isErrorObject?: boolean;
    remoteExecutionStartTime?: number;
    remoteExecutionEndTime?: number;
    logUrl?: string;
    instanceId?: string;
    executionId?: string;
    memoryUsage?: NodeJS.MemoryUsage;
}
export interface CallingContext {
    call: FunctionCall;
    startTime: number;
    logUrl?: string;
    executionId?: string;
    instanceId?: string;
}
export interface ModuleType {
    [name: string]: any;
}
export declare function createErrorResponse(err: any, { call, startTime, logUrl, executionId }: CallingContext): FunctionReturn;
export interface WrapperOptions {
    /**
     * Logging function for console.log/warn/error output. Only available in
     * child process mode. This is mainly useful for debugging the "local"
     * mode which runs code locally. In real clouds the logs will end up in the
     * cloud logging service (e.g. Cloudwatch Logs, or Google Stackdriver logs).
     * Defaults to console.log.
     */
    wrapperLog?: (msg: string) => void;
    childProcess?: boolean;
    childProcessMemoryLimitMb?: number;
    childProcessTimeoutMs?: number;
    childProcessEnvironment?: {
        [key: string]: string;
    };
    childDir?: string;
    wrapperVerbose?: boolean;
}
export declare const WrapperOptionDefaults: Required<WrapperOptions>;
declare type CpuUsageCallback = (usage: CpuMeasurement) => void;
export declare class Wrapper {
    executing: boolean;
    protected verbose: boolean;
    protected funcs: ModuleType;
    protected child?: childProcess.ChildProcess;
    protected log: (msg: string) => void;
    protected deferred?: Deferred<FunctionReturn>;
    readonly options: Required<WrapperOptions>;
    protected monitoringTimer?: NodeJS.Timer;
    constructor(fModule: ModuleType, options?: WrapperOptions);
    protected lookupFunction(request: object): AnyFunction;
    protected stopCpuMonitoring(): void;
    protected startCpuMonitoring(pid: number, callback: CpuUsageCallback): void;
    stop(): void;
    execute(callingContext: CallingContext, callback?: CpuUsageCallback, overrideTimeout?: number): Promise<FunctionReturn>;
    protected logLines: (msg: string) => void;
    protected setupChildProcess(): childProcess.ChildProcess;
}
export interface CpuMeasurement {
    stime: number;
    utime: number;
    elapsed: number;
}
export {};
